Helper function to merge the original kernel configuration with the best hyperparameters found by standard Grid Search (tune_random_machines).

# S3 method for class 'random_machines_tune'
as_kernels(tune_results, kernel_mix)

Arguments

tune_results

The object returned by tune_random_machines.

kernel_mix

Original kernel configuration.