Helper function to merge the original kernel configuration with the best hyperparameters found by Optuna.

# S3 method for class 'random_machines_tune_optuna'
as_kernels(tune_results, kernel_mix)

Arguments

tune_results

The object returned by tune_random_machines_optuna.

kernel_mix

The original list of base kernel configurations.

Value

A list of optimized kernel configurations ready for random_machines.