This function retrieves all hyperparameters used in the underlying Python model sksurv.svm.FastKernelSurvivalSVM by calling its get_params() method. The returned list contains all estimator arguments, including kernel specification, regularization strength, optimizer settings, and kernel parameters (e.g., gamma, degree, coef0).

get_params_fastsvm(object, ...)

Arguments

object

An object of class "fastsvm".

...

Additional arguments (unused; included for S3 method compatibility).

Value

A named list of hyperparameters corresponding to those returned by the Python method FastKernelSurvivalSVM.get_params().

Details

This can be useful for reproducibility, model inspection, or when saving configurations for automated tuning workflows.

Examples

if (reticulate::py_module_available("sksurv")) {
  set.seed(123)

  df <- data.frame(
    time = rexp(40, 0.2),
    status = rbinom(40, 1, 0.6),
    x1 = rnorm(40),
    x2 = rnorm(40)
  )

  fit <- fastsvm(
    data = df,
    time_col = "time",
    delta_col = "status",
    kernel = "rbf",
    alpha = 0.5,
    rank_ratio = 0.3
  )

  get_params_fastsvm(fit)
}
#> $alpha
#> [1] 0.5
#> 
#> $coef0
#> [1] 1
#> 
#> $degree
#> [1] 3
#> 
#> $fit_intercept
#> [1] TRUE
#> 
#> $gamma
#> NULL
#> 
#> $kernel
#> [1] "rbf"
#> 
#> $kernel_params
#> NULL
#> 
#> $max_iter
#> [1] 20
#> 
#> $optimizer
#> [1] "rbtree"
#> 
#> $random_state
#> NULL
#> 
#> $rank_ratio
#> [1] 0.3
#> 
#> $timeit
#> [1] FALSE
#> 
#> $tol
#> NULL
#> 
#> $verbose
#> [1] FALSE
#>