This method prints a compact summary of the fitted "fastsvm" model, including the number of observations, number of covariates, kernel type, and key hyperparameters.

# S3 method for class 'fastsvm'
print(x, ...)

Arguments

x

An object of class "fastsvm".

...

Additional arguments passed to methods.