Extracts key information from a fitted "fastsvm" model, including the number of observations, number of covariates, kernel specification, hyperparameters, and a summary of the sample-wise coefficients coef_ returned by the Python model.

# S3 method for class 'fastsvm'
summary(object, ...)

Arguments

object

An object of class "fastsvm".

...

Additional arguments passed to methods.

Value

An object of class "summary.fastsvm".