R/tune_optuna.R
as_kernels.random_machines_tune_optuna.RdHelper function to merge the original kernel configuration with the best hyperparameters found by Optuna.
# S3 method for class 'random_machines_tune_optuna'
as_kernels(tune_results, kernel_mix)A list of optimized kernel configurations ready for random_machines.