R/tune_optuna.R
opt_int.Rd
Helper function to define an integer hyperparameter range for Bayesian optimization.
opt_int(low, high, log = FALSE, step = 1L)
Integer. The lower bound of the range.
Integer. The upper bound of the range.
Logical. If TRUE, the value is sampled from the range in the log domain.
TRUE
Integer. The discretization step (default 1).
An object of class "opt_param_def".
"opt_param_def"
# Define search for polynomial degree between 2 and 5 space_degree <- opt_int(2, 5)